@@ -13,6 +13,8 @@ from pypdfium2._cli import (
     toc,
     merge,
     tile,
+    extract_text,
+    find_pageobjects,
 )
 
 try:
@@ -23,12 +25,14 @@ else:
     have_argcomplete = True
 
 
-Subcommands = dict(
-    render = render,
-    toc = toc,
-    merge = merge,
-    tile = tile,
-)
+Subcommands = {
+    "render": render,
+    "toc": toc,
+    "merge": merge,
+    "tile": tile,
+    "extract-text": extract_text,
+    "find-pageobjects": find_pageobjects,
+}
 
 
 def parse_args(argv=sys.argv[1:]):
@@ -43,10 +47,7 @@ def parse_args(argv=sys.argv[1:]):
         version = "pypdfium2 %s (libpdfium %s)" % (V_PYPDFIUM2, V_LIBPDFIUM),
     )
     
-    subparsers = parser.add_subparsers(
-        dest = "subcommand",
-        required = True,
-    )
+    subparsers = parser.add_subparsers(dest="subcommand")
     for cmd in Subcommands.values():
         cmd.attach_parser(subparsers)
     
@@ -58,4 +59,7 @@ def parse_args(argv=sys.argv[1:]):
 
 def main():
     args = parse_args()
+    if not args.subcommand:
+        print("One of the following subcommands must be given: %s" % [sc for sc in Subcommands.keys()])
+        return
     Subcommands[args.subcommand].main(args)
